<?php

namespace SGalinski\SgNews\Service;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Configuration\ConfigurationManager;
use TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface;
use TYPO3\CMS\Extbase\Configuration\Exception\InvalidConfigurationTypeException;

/**
 * This service provides helper function for dealing with plugin configuration
 */
class ConfigurationService implements SingletonInterface {

	/**
	 * @var array
	 */
	protected $tsConfig;

	/**
	 * Returns the desired config value either from TypoScript settings or flexform config
	 * If the user set 'System default' in the flexform, the value will be fetched from TS
	 *
	 * @param string $key
	 * @param array $settings
	 * @throws InvalidConfigurationTypeException
	 * @return string
	 */
	public function getConfiguration($key, $settings): string {
		if (!$this->tsConfig) {
			$configurationManager = GeneralUtility::makeInstance(ConfigurationManager::class);
			$this->tsConfig = $configurationManager->getConfiguration(ConfigurationManagerInterface::CONFIGURATION_TYPE_FULL_TYPOSCRIPT);
		}
		if ($settings[$key] === 'typoscript') {
			return $this->tsConfig['plugin.']['tx_sgnews.']['settings.'][$key];
		}
		return $settings[$key];
	}
}
